@@ -15,9 +15,9 @@ import tkinter as tk
 from tkinter import messagebox, simpledialog
 from tkinter.filedialog import askopenfilename, asksaveasfilename
 
-from stanfordkarel.karel import Karel
-from stanfordkarel.karel_canvas import KarelCanvas
-from stanfordkarel.karel_definitions import (
+from .karel import Karel
+from .karel_canvas import KarelCanvas
+from .karel_definitions import (
     COLOR_MAP,
     DEFAULT_ICON,
     DIRECTIONS_MAP,
@@ -27,7 +27,7 @@ from stanfordkarel.karel_definitions import (
     PAD_X,
     PAD_Y,
 )
-from stanfordkarel.karel_world import KarelWorld
+from .karel_world import KarelWorld
 
 MIN_DIMENSIONS = 1
 MAX_DIMENSIONS = 50
@@ -382,7 +382,7 @@ class WorldBuilderApplication(tk.Frame):
         elif action == "reset_corner":
             apply_function(self.world.reset_corner)
         elif action == "paint_corner":
-            apply_function(self.world.paint_corner, COLOR_MAP[self.color_var.get()])
+            apply_function(self.world.paint_corner, self.color_var.get())
         elif action == "add_wall":
             wall = self.canvas.find_nearest_wall(event.x, event.y, avenue, street)
             if wall:
